==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
var RectChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RectChangedEventArgsDescriptionMetadata, _super);
    function RectChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RectChangedEventArgsDescriptionMetadata.b = function (a) {
        if (RectChangedEventArgsDescriptionMetadata.a == null) {
            RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(RectChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(RectChangedEventArgsDescriptionMetadata.a);
    };
    RectChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldRect", "Rect");
        a.item("NewRect", "Rect");
    };
    RectChangedEventArgsDescriptionMetadata.d = function (a) {
        RectChangedEventArgsDescriptionMetadata.b(a);
        a.u("RectChangedEventArgs", function () { return new RectChangedEventArgsDescription(); });
        a.t("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
    };
    RectChangedEventArgsDescriptionMetadata.$t = markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
}(Base));
export { RectChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
var RectChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RectChangedEventArgsDescriptionMetadata, _super);
    function RectChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RectChangedEventArgsDescriptionMetadata.b = function (a) {
        if (RectChangedEventArgsDescriptionMetadata.a == null) {
            RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(RectChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(RectChangedEventArgsDescriptionMetadata.a);
    };
    RectChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldRect", "Rect");
        a.item("NewRect", "Rect");
    };
    RectChangedEventArgsDescriptionMetadata.d = function (a) {
        RectChangedEventArgsDescriptionMetadata.b(a);
        a.aa("RectChangedEventArgs", function () { return new RectChangedEventArgsDescription(); });
        a.z("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
    };
    RectChangedEventArgsDescriptionMetadata.$t = markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
}(Base));
export { RectChangedEventArgsDescriptionMetadata };
